==> gmt_6.4.0+dfsg.orig.tar.xz: gmt-6.4.0/CONTRIBUTING.md <==
# Contributing Guidelines

**First of all, thank you for considering contributing to the project.**

This is a community-driven project, so it's people like you that make it useful and
successful.
These are some of the many ways to contribute:

* :bug: Submitting bug reports and feature requests
* :memo: Writing tutorials or examples
* :mag: Fixing typos and improving to the documentation
* :bulb: Writing code for everyone to use

If you get stuck at any point you can create an [issue](https://github.com/GenericMappingTools/gmt/issues)
on GitHub or contact us at one of the other channels mentioned below.

For more information on contributing to open source projects,
[GitHub's own guide](https://guides.github.com/activities/contributing-to-open-source/)
is a great starting point if you are new to version control.


## Ground Rules

The goal is to maintain a diverse community that's pleasant for everyone.
**Please be considerate and respectful of others**.
Everyone must abide by our [Code of Conduct](CODE_OF_CONDUCT.md) and we encourage all to
read it carefully.


## Quick links

* [Ways to Contribute](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#ways-to-contribute)
* [Getting Help](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#getting-help)
* [Reporting a Bug](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#reporting-a-bug)
* [Contributing Documentation](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#contributing-documentation)
* [Contributing Code](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#contributing-code)

==> gmt_6.5.0+dfsg.orig.tar.xz: gmt-6.5.0/CONTRIBUTING.md <==
# Contributing Guidelines

**First of all, thank you for considering contributing to the project.**

This is a community-driven project, so it's people like you that make it useful and
successful.
These are some of the many ways to contribute:

* :bug: Submitting bug reports and feature requests
* :memo: Writing tutorials or examples
* :mag: Fixing typos and improving to the documentation
* :bulb: Writing code for everyone to use

If you get stuck at any point you can create an [issue](https://github.com/GenericMappingTools/gmt/issues)
on GitHub or contact us at one of the other channels mentioned below.

For more information on contributing to open source projects,
[GitHub's own guide](https://guides.github.com/activities/contributing-to-open-source/)
is a great starting point if you are new to version control.


## Ground Rules

The goal is to maintain a diverse community that's pleasant for everyone.
**Please be considerate and respectful of others**.
Everyone must abide by our [Code of Conduct](https://github.com/GenericMappingTools/.github/blob/main/CODE_OF_CONDUCT.md)
and we encourage all to read it carefully.


## Quick links

* [Ways to Contribute](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#ways-to-contribute)
* [Getting Help](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#getting-help)
* [Reporting a Bug](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#reporting-a-bug)
* [Contributing Documentation](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#contributing-documentation)
* [Contributing Code](https://docs.generic-mapping-tools.org/dev/devdocs/contributing.html#contributing-code)
